@@ -78,7 +78,7 @@ class Server:
             """
             if id:
                 for player in self.players:
-                    if str(player.id) == str(id).lower():
+                    if str(player.id) == str(id).lower() or str(player.name)==str(id):
                         return player
 
         def get_version(self):
